/*******************************************************************************
*
*                    USING THE ADC IN FREE RUNNING MODE
*                    ----------------------------------
*
*   Filename:                                    
*   Autor:                  David Kress
*
*   Version:                1.0
*   Date:                   5. December 2010
*   Built with:             ATMEL AVR Studio 4.14 and AVR-GCC; Optimization -01
*
*   Description:            This programm is a simple example hwo to use the
*                           ATMEGA16 ADC in free running mode.
*                           The program clears the ADIF Flag by
*                           writing a one to it. Then the program waits until
*                           the running conversion is finished.
*                           When the conversion is  finished, the value is
*                           compared with 512 and a LED indicates the result.
*                           
*   What you can learn:     - Select AVCC as ADC voltagereference
*                           - Select an ADC clockprescaler
*                           - Select an ADC input with the ADC MUX 
*                           - Enable the ADC
*                           - Start the freerunning mode
*                           - Read and use the result
*
*   Clock source:           - Any 1MHz clock
*
*   Recommended             - High: 0x99
*   Fuse settings:          - Low:  0xE1
*
*
*
*   Schematic:       ___________________
*                   |      ATMEGA16     |
*          Vcc ---->|Vcc                |
*          Vcc ---->|RESET              |
*                   |              AREF |----
*          GND ---->|GND                |   |
*                   |                   |  ===
*          Vcc      |                   |   |
*           |       |                   |  GND
*           |       |                   |             
*          |P|      |                   |
*          |O|      |                   |
*          |T|----->| PA0  (ADC0)       |             
*          |I|      |                   |
*           |       |                   |
*           |       |               PB0 |----> DOUT     
*          GND      |                   |
*                   |                   |
*
*
*******************************************************************************/


#include <avr/io.h>

#define ADATE 5                         // Definition is missing in
                                        // some Versions of AVR Studio

int main(void)
{
    DDRB = 0x01;                        // Setup PB0 as output

    ADMUX |= (1<<REFS0);                // Set reference to AVcc

    ADCSRA |= (1<<ADEN)|(1<<ADATE)|     // Enable ADC, Enable auto Triggering
              (1<<ADPS2)|(1<<ADSC);     // Set prescaler to 16
                                        // Fadc=Fcpu/prescaler=1000000/16=62.5kHz
                                        // Fadc should be between 50kHz and 200kHz
                                        // Start first conversion
  
    for(;;)                             // Endless loop;
    {
            while(!(ADCSRA&(1<<ADSC))); // Wait until a conversion is finished

			if(ADC>=512)                // Compare the conversionresult with 512
                PORTB |= 0x01;          // If larger, set PB0
            else
                PORTB &= ~0x01;         // If smaller, reset PB0

    }                                   // main() will never be left

    return 0;                           // This line will never be executed
}


